diff --git a/print.c b/print.c
index 9b6ec2a010ff655fda392d21a9f6792b492a8017..1bdfc07f85de0a4181f097033ef26247070b737a 100644
--- a/print.c
+++ b/print.c
@@ -351,6 +351,7 @@ const struct board_info_url boards_url[] = {
 	{ "T-Online",		"S-100",		"http://wiki.freifunk-hannover.de/T-Online_S_100" },
 	{ "Tyan",		"iS5375-1U",		"http://www.tyan.com/product_board_detail.aspx?pid=610" },
 	{ "Tyan",		"S1846",		"http://www.tyan.com/archive/products/html/tsunamiatx.html" },
+	{ "Tyan",		"S2466",		"http://www.tyan.com/product_board_detail.aspx?pid=461" },
 	{ "Tyan",		"S2881",		"http://www.tyan.com/product_board_detail.aspx?pid=115" },
 	{ "Tyan",		"S2882",		"http://www.tyan.com/product_board_detail.aspx?pid=121" },
 	{ "Tyan",		"S2882-D",		"http://www.tyan.com/product_board_detail.aspx?pid=127" },
@@ -380,10 +381,12 @@ const struct board_info_url boards_url[] = {
 	{ "Acorp",		"6A815EPD",		"http://web.archive.org/web/20021206163652/www.acorp.com.tw/English/default.asp" },
 	{ "agami",		"Aruma",		"http://web.archive.org/web/20080212111524/http://www.agami.com/site/ais-6000-series" },
 	{ "Albatron",		"PM266A Pro",		"http://www.albatron.com.tw/English/Product/MB/pro_detail.asp?rlink=Overview&no=56" }, /* FIXME */
+	{ "AOpen",		"vKM400Am-S",		"http://usa.aopen.com/products_detail.aspx?Auno=824" },
 	{ "Artec Group",	"DBE61",		"http://wiki.thincan.org/DBE61" },
 	{ "Artec Group",	"DBE62",		"http://wiki.thincan.org/DBE62" },
 	{ "ASUS",		"A7V8X-MX SE",		"http://www.asus.com/product.aspx?P_ID=1guVBT1qV5oqhHyZ" },
 	{ "ASUS",		"P4B266",		"http://www.ciao.co.uk/ASUS_Intel_845D_Chipset_P4B266__5409807#productdetail" },
+	{ "ASUS",		"P4P800-E Deluxe",	"http://www.asus.com/product.aspx?P_ID=INIJUvLlif7LHp3g" },
 	{ "ASUS",		"P5A",			"ftp://ftp.asus.com.tw/pub/ASUS/mb/sock7/ali/p5a/" },
 	{ "Biostar",		"P4M80-M4",		"http://www.biostar-usa.com/mbdetails.asp?model=p4m80-m4" },
 	{ "Elitegroup",		"K7VTA3",		"http://www.ecs.com.tw/ECSWebSite/Products/ProductsDetail.aspx?detailid=264&CategoryID=1&DetailName=Specification&MenuID=52&LanID=0" },
@@ -420,6 +423,9 @@ const struct board_info_url boards_url[] = {
  
 	/* Verified non-working boards (for now). */
 	{ "Abit",		"IS-10",		"http://www.abit.com.tw/page/en/motherboard/motherboard_detail.php?pMODEL_NAME=IS-10&fMTYPE=Socket+478" },
+	{ "ASRock",		"K7VT4A+",		"http://www.asrock.com/mb/overview.asp?Model=K7VT4A%%2b&s=" },
+	{ "ASUS",		"A7V600-X",		"http://www.asus.com/product.aspx?P_ID=L2XYS0rmtCjeOr4k" },
+	{ "ASUS",		"M2N68",		"http://www.asus.com/product.aspx?P_ID=iDZQ9yNK2CbKW6Zv"},
 	{ "ASUS",		"M3N78 Pro",		"http://www.asus.com/product.aspx?P_ID=DVvm9CU0G1bCC4gp" },
 	{ "ASUS",		"MEW-AM",		"ftp://ftp.asus.com.tw/pub/ASUS/mb/sock370/810/mew-am/" },
 	{ "ASUS",		"MEW-VM",		"http://www.elhvb.com/mboards/OEM/HP/manual/ASUS%20MEW-VM.htm" },
diff --git a/board_enable.c b/board_enable.c
index 5381e82b187fa5af02d193d98df4113462181597..fc8feb05d5f051e3fdd21180033542a5c2208609 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -637,7 +637,7 @@ static int it8705_rom_write_enable(const char *name)
 }
 
 /**
  * Suited for A-Open vKM400 AM-S: VIA KM400 + VT8237 + IT8705F.
  */
 static int board_aopen_vkm400(const char *name)
 {
@@ -866,7 +866,7 @@ static int board_asus_a7v8x(const char *name)
 }
 
 /**
- * Suited for Asus P4P800-E: Intel Intel 865PE + ICH5R.
+ * Suited for Asus P4P800-E Deluxe: Intel Intel 865PE + ICH5R.
  */
 static int board_asus_p4p800(const char *name)
 {
@@ -918,7 +918,7 @@ struct board_pciid_enable board_pciid_enables[] = {
 	{0x8086, 0x1130,      0,      0,  0x105a, 0x0d30, 0x105a, 0x4d33, "acorp",      "6a815epd",    "Acorp",       "6A815EPD",           board_acorp_6a815epd},
 	{0x1022, 0x746B, 0x1022, 0x36C0,       0,      0,      0,      0, "AGAMI",      "ARUMA",       "agami",       "Aruma",              w83627hf_gpio24_raise_2e},
 	{0x1106, 0x3177, 0x17F2, 0x3177,  0x1106, 0x3148, 0x17F2, 0x3148, NULL,         NULL,          "Albatron",    "PM266A*",            board_epox_ep_8k5a2},
-	{0x1106, 0x3205, 0x1106, 0x3205,  0x10EC, 0x8139, 0xA0A0, 0x0477, NULL,         NULL,          "AOpen",       "vKM400 AM-s",        board_aopen_vkm400},
+	{0x1106, 0x3205, 0x1106, 0x3205,  0x10EC, 0x8139, 0xA0A0, 0x0477, NULL,         NULL,          "AOpen",       "vKM400Am-S",         board_aopen_vkm400},
 	{0x1022, 0x2090,      0,      0,  0x1022, 0x2080,      0,      0, "artecgroup", "dbe61",       "Artec Group", "DBE61",              board_artecgroup_dbe6x},
 	{0x1022, 0x2090,      0,      0,  0x1022, 0x2080,      0,      0, "artecgroup", "dbe62",       "Artec Group", "DBE62",              board_artecgroup_dbe6x},
 	{0x1106, 0x3189, 0x1043, 0x807F,  0x1106, 0x3177, 0x1043, 0x808C, NULL,         NULL,          "ASUS",        "A7V8X",              board_asus_a7v8x},
@@ -1022,6 +1022,7 @@ const struct board_info boards_ok[] = {
 	{ "T-Online",		"S-100", },
 	{ "Tyan",		"iS5375-1U", },
 	{ "Tyan",		"S1846", },
+	{ "Tyan",		"S2466", },
 	{ "Tyan",		"S2881", },
 	{ "Tyan",		"S2882", },
 	{ "Tyan",		"S2882-D", },
@@ -1054,6 +1055,9 @@ const struct board_info boards_ok[] = {
 const struct board_info boards_bad[] = {
 	/* Verified non-working boards (for now). */
 	{ "Abit",		"IS-10", },
+	{ "ASRock",		"K7VT4A+", },
+	{ "ASUS",		"A7V600-X", },
+	{ "ASUS",		"M2N68", },
 	{ "ASUS",		"M3N78 Pro", },
 	{ "ASUS",		"MEW-AM", },
 	{ "ASUS",		"MEW-VM", },
@@ -637,7 +637,7 @@ static int it8705_rom_write_enable(const char *name)
 
 /**
- * Suited for A-Open vKM400 AM-S: VIA KM400 + VT8237 + IT8705F.
+ * Suited for AOpen vKM400Am-S: VIA KM400 + VT8237 + IT8705F.
  */
 static int board_aopen_vkm400(const char *name)